@@ -38,41 +38,38 @@
 #include <KGameTheme>
 #include <KLocale>
 #include <QPainter>
-#include <QPixmapCache>
-#include <KPixmapCache>
-#include <KSvgRenderer>
-#include <KStandardDirs>
 #include <QGraphicsView>
 
+#include <KGameRenderer>
+#include <KGameRenderedItem>
+
 GameScene::GameScene(Game* p_game) : m_game(p_game)
 {
     connect(p_game, SIGNAL(gameStarted()), this, SLOT(start()));
-    connect(p_game, SIGNAL(pauseChanged(bool, bool)), this, SLOT(setPaused(bool, bool)));
+    connect(p_game, SIGNAL(pauseChanged(bool,bool)), this, SLOT(setPaused(bool,bool)));
     connect(p_game, SIGNAL(bombCreated(Bomb*)), this, SLOT(createBombItem(Bomb*)));
-    connect(p_game, SIGNAL(infoChanged(Game::InformationTypes)), this, SLOT(updateInfo(const Game::InformationTypes)));
-
-    // Set the pixmap cache limit to improve performance
-    setItemIndexMethod(NoIndex);
-    m_cache = new KPixmapCache("granatier_cache");
-    m_cache->setCacheLimit(3 * 1024);
+    connect(p_game, SIGNAL(infoChanged(Game::InformationTypes)), this, SLOT(updateInfo(Game::InformationTypes)));
     
-    m_pixmapCache = new QPixmapCache;
     m_SvgScaleFactor = 1;
-
+    
     // Load the selected SVG file
-    m_rendererSelectedTheme = new KSvgRenderer();
+    m_rendererSelectedTheme = 0;
     loadTheme();
+    //uncomment this if the crash in KSharedDataCache appears again
+    //m_rendererSelectedTheme->setStrategyEnabled(KGameRenderer::UseDiskCache, false);
     // Load the default SVG file as fallback
     bool selectedThemeIsDefault = true;
     m_rendererDefaultTheme = 0;
-    if(Settings::self()->theme() != "themes/granatier.desktop")
+    
+    if(Settings::self()->theme() != "themes/granatier.desktop" || m_rendererSelectedTheme == 0)
     {
         selectedThemeIsDefault = false;
-        m_rendererDefaultTheme = new KSvgRenderer();
-        m_rendererDefaultTheme->load(KStandardDirs::locate("appdata", "themes/granatier.svgz"));
+        m_rendererDefaultTheme = new KGameRenderer("themes/granatier.desktop");
+        //uncomment this if the crash in KSharedDataCache appears again
+        //m_rendererDefaultTheme->setStrategyEnabled(KGameRenderer::UseDiskCache, false);
     }
     
-    if(selectedThemeIsDefault || m_rendererSelectedTheme->elementExists("background"))
+    if(selectedThemeIsDefault || m_rendererSelectedTheme->spriteExists("background"))
     {
         m_rendererBackground = m_rendererSelectedTheme;
     }
@@ -82,16 +79,16 @@ GameScene::GameScene(Game* p_game) : m_game(p_game)
     }
     
     // set the renderer for the arena items TODO: add all the arena items
-    if(selectedThemeIsDefault || (m_rendererSelectedTheme->elementExists("arena_ground") &&
-        m_rendererSelectedTheme->elementExists("arena_wall") &&
-        m_rendererSelectedTheme->elementExists("arena_block") &&
-        m_rendererSelectedTheme->elementExists("arena_block_highlight") &&
-        m_rendererSelectedTheme->elementExists("arena_ice") &&
-        m_rendererSelectedTheme->elementExists("arena_bomb_mortar") &&
-        m_rendererSelectedTheme->elementExists("arena_arrow_up") &&
-        m_rendererSelectedTheme->elementExists("arena_arrow_right") &&
-        m_rendererSelectedTheme->elementExists("arena_arrow_down") &&
-        m_rendererSelectedTheme->elementExists("arena_arrow_left")))
+    if(selectedThemeIsDefault || (m_rendererSelectedTheme->spriteExists("arena_ground") &&
+        m_rendererSelectedTheme->spriteExists("arena_wall") &&
+        m_rendererSelectedTheme->spriteExists("arena_block") &&
+        m_rendererSelectedTheme->spriteExists("arena_block_highlight") &&
+        m_rendererSelectedTheme->spriteExists("arena_ice") &&
+        m_rendererSelectedTheme->spriteExists("arena_bomb_mortar") &&
+        m_rendererSelectedTheme->spriteExists("arena_arrow_up") &&
+        m_rendererSelectedTheme->spriteExists("arena_arrow_right") &&
+        m_rendererSelectedTheme->spriteExists("arena_arrow_down") &&
+        m_rendererSelectedTheme->spriteExists("arena_arrow_left")))
     {
         m_rendererArenaItems = m_rendererSelectedTheme;
     }
@@ -99,20 +96,21 @@ GameScene::GameScene(Game* p_game) : m_game(p_game)
     {
         m_rendererArenaItems = m_rendererDefaultTheme;
     }
+    
     // set the renderer for the bonus items TODO: add all the bonus items
-    if(selectedThemeIsDefault || (m_rendererSelectedTheme->elementExists("bonus_speed") &&
-        m_rendererSelectedTheme->elementExists("bonus_bomb") &&
-        m_rendererSelectedTheme->elementExists("bonus_power") &&
-        m_rendererSelectedTheme->elementExists("bonus_shield") &&
-        m_rendererSelectedTheme->elementExists("bonus_throw") &&
-        m_rendererSelectedTheme->elementExists("bonus_kick") &&
-        m_rendererSelectedTheme->elementExists("bonus_bad_slow") &&
-        m_rendererSelectedTheme->elementExists("bonus_bad_hyperactive") &&
-        m_rendererSelectedTheme->elementExists("bonus_bad_mirror") &&
-        m_rendererSelectedTheme->elementExists("bonus_bad_scatty") &&
-        m_rendererSelectedTheme->elementExists("bonus_bad_restrain") &&
-        m_rendererSelectedTheme->elementExists("bonus_neutral_pandora") &&
-        m_rendererSelectedTheme->elementExists("bonus_neutral_resurrect")))
+    if(selectedThemeIsDefault || (m_rendererSelectedTheme->spriteExists("bonus_speed") &&
+        m_rendererSelectedTheme->spriteExists("bonus_bomb") &&
+        m_rendererSelectedTheme->spriteExists("bonus_power") &&
+        m_rendererSelectedTheme->spriteExists("bonus_shield") &&
+        m_rendererSelectedTheme->spriteExists("bonus_throw") &&
+        m_rendererSelectedTheme->spriteExists("bonus_kick") &&
+        m_rendererSelectedTheme->spriteExists("bonus_bad_slow") &&
+        m_rendererSelectedTheme->spriteExists("bonus_bad_hyperactive") &&
+        m_rendererSelectedTheme->spriteExists("bonus_bad_mirror") &&
+        m_rendererSelectedTheme->spriteExists("bonus_bad_scatty") &&
+        m_rendererSelectedTheme->spriteExists("bonus_bad_restrain") &&
+        m_rendererSelectedTheme->spriteExists("bonus_neutral_pandora") &&
+        m_rendererSelectedTheme->spriteExists("bonus_neutral_resurrect")))
     {
         m_rendererBonusItems = m_rendererSelectedTheme;
     }
@@ -120,13 +118,14 @@ GameScene::GameScene(Game* p_game) : m_game(p_game)
     {
         m_rendererBonusItems = m_rendererDefaultTheme;
     }
+    
     // set the renderer for the bomb items
-    if(selectedThemeIsDefault || (m_rendererSelectedTheme->elementExists("bomb") &&
-        m_rendererSelectedTheme->elementExists("bomb_blast_core_0") &&
-        m_rendererSelectedTheme->elementExists("bomb_blast_north_0") &&
-        m_rendererSelectedTheme->elementExists("bomb_blast_east_0") &&
-        m_rendererSelectedTheme->elementExists("bomb_blast_south_0") &&
-        m_rendererSelectedTheme->elementExists("bomb_blast_west_0")))
+    if(selectedThemeIsDefault || (m_rendererSelectedTheme->spriteExists("bomb") &&
+        m_rendererSelectedTheme->spriteExists("bomb_blast_core_0") &&
+        m_rendererSelectedTheme->spriteExists("bomb_blast_north_0") &&
+        m_rendererSelectedTheme->spriteExists("bomb_blast_east_0") &&
+        m_rendererSelectedTheme->spriteExists("bomb_blast_south_0") &&
+        m_rendererSelectedTheme->spriteExists("bomb_blast_west_0")))
     {
         m_rendererBombItems = m_rendererSelectedTheme;
     }
@@ -136,8 +135,8 @@ GameScene::GameScene(Game* p_game) : m_game(p_game)
     }
     
     // set the renderer for the score items
-    if(selectedThemeIsDefault || (m_rendererSelectedTheme->elementExists("score_star_enabled") &&
-        m_rendererSelectedTheme->elementExists("score_star_disabled")))
+    if(selectedThemeIsDefault || (m_rendererSelectedTheme->spriteExists("score_star_enabled") &&
+        m_rendererSelectedTheme->spriteExists("score_star_disabled")))
     {
         m_rendererScoreItems = m_rendererSelectedTheme;
     }
@@ -148,10 +147,15 @@ GameScene::GameScene(Game* p_game) : m_game(p_game)
 
     // Create the PlayerItems and the points labels
     QList <Player*> players = p_game->getPlayers();
+    
     PlayerItem* playerItem;
     for(int i = 0; i < players.size(); i++)
     {
-        playerItem = new PlayerItem(players[i]);
+        KGameRenderer* playerRenderer = new KGameRenderer(players[i]->getDesktopFilePath());
+        //uncomment this if the crash in KSharedDataCache appears again
+        //playerRenderer->setStrategyEnabled(KGameRenderer::UseDiskCache, false);
+        m_mapRendererPlayerItems.insert(players[i], playerRenderer);
+        playerItem = new PlayerItem(players[i], playerRenderer);
         // Corrects the position of the player
         playerItem->update(players[i]->getX(), players[i]->getY());
         // Stops the player animation
@@ -159,9 +163,10 @@ GameScene::GameScene(Game* p_game) : m_game(p_game)
         
         m_playerItems.append(playerItem);
         
+        connect(this, SIGNAL(resizeGraphics(qreal)), playerItem, SLOT(updateGraphics(qreal)));
         connect (playerItem, SIGNAL(bonusItemTaken(BonusItem*)), this, SLOT(removeBonusItem(BonusItem*)));
     }
-
+    
     // The remaining time
     m_remainingTimeLabel = new QGraphicsTextItem(i18n("0:00"));
     m_remainingTimeLabel->setFont(QFont("Helvetica", 15, QFont::Bold, false));
@@ -177,26 +182,19 @@ GameScene::GameScene(Game* p_game) : m_game(p_game)
                  m_game->getArena()->getNbColumns()*Cell::SIZE,
                  m_game->getArena()->getNbRows()*Cell::SIZE + m_remainingTimeLabel->boundingRect().height());
     
-    //create the background
-    QSize backgroundSize = m_rendererBackground->boundsOnElement("background").size().toSize();
-    //paint svg to pixmap
-    QPixmap pixmapBG = backgroundSize;
-    pixmapBG.fill(Qt::black);
-    QPainter painterBG(&pixmapBG);
-    m_rendererBackground->render(&painterBG, "background");
-    painterBG.end();
-    
-    //set pixmap
-    m_arenaBackground = new QGraphicsPixmapItem();
+    //create the background    
+    //uncomment this if the crash in KSharedDataCache appears again
+    //m_rendererBackground->setStrategyEnabled(KGameRenderer::UseDiskCache, false); //TODO: why does it crash with disc cache on?
+    m_arenaBackground = new KGameRenderedItem(m_rendererBackground, "background");
     m_arenaBackground->setZValue(-5);
-    m_arenaBackground->setPixmap(pixmapBG);
     m_arenaBackground->setPos(0, 0);
-    m_arenaBackground->setShapeMode(QGraphicsPixmapItem::BoundingRectShape);
-    m_arenaBackground->setCacheMode(QGraphicsItem::DeviceCoordinateCache, backgroundSize);
+    m_arenaBackground->setCacheMode(QGraphicsItem::NoCache);
     addItem(m_arenaBackground);
     
     // create the info sidebar
-    m_infoSidebar = new InfoSidebar(m_game, /*TODO*/m_rendererBonusItems, this);
+    m_infoSidebar = new InfoSidebar(m_game, this);
+    connect(this, SIGNAL(resizeGraphics(qreal)), m_infoSidebar, SLOT(updateGraphics(qreal)));
+    
     //update the sceneRect
     QRectF oldSceneRect = sceneRect();
     QRectF sidebarRect = m_infoSidebar->rect();
@@ -209,29 +207,40 @@ GameScene::GameScene(Game* p_game) : m_game(p_game)
     setSceneRect(newSceneRect);
     
     // create the info overlay
-    m_infoOverlay = new InfoOverlay(m_game, m_rendererScoreItems, this);
+    m_infoOverlay = new InfoOverlay(m_game, this);
+    connect(this, SIGNAL(resizeGraphics(qreal)), m_infoOverlay, SLOT(updateGraphics(qreal)));
     
     init();
+    
+    //at this point, sceneRect() has the minimum size for the scene
+    m_minSize = sceneRect();
+    m_minSize.setX((int) ((int)m_minSize.x() - ((int)m_minSize.x() % (int)Cell::SIZE)) - Cell::SIZE/4);
+    m_minSize.setY((int) ((int)m_minSize.y() - ((int)m_minSize.y() % (int)Cell::SIZE)) - Cell::SIZE/4);
+    m_minSize.setHeight(((int) (m_minSize.height() / Cell::SIZE) + 1) * Cell::SIZE);
+    m_minSize.setWidth(((int) (m_minSize.width() / Cell::SIZE) + 1) * Cell::SIZE);
+    setSceneRect(m_minSize);
 }
 
 void GameScene::init()
 {
     // Create the ArenaItems
     m_arenaItem = new ArenaItem**[m_game->getArena()->getNbRows()];
+    
     for (int i = 0; i < m_game->getArena()->getNbRows(); ++i)
     {
         m_arenaItem[i] = new ArenaItem*[m_game->getArena()->getNbColumns()];
         for (int j = 0; j < m_game->getArena()->getNbColumns(); ++j)
         {
             // Create the ArenaItem and set the image
-            ArenaItem* arenaItem = new ArenaItem(j * Cell::SIZE, i * Cell::SIZE);
-            arenaItem->setSharedRenderer(m_rendererArenaItems);
+            ArenaItem* arenaItem = new ArenaItem(j * Cell::SIZE, i * Cell::SIZE, m_rendererArenaItems, "");
+            connect(this, SIGNAL(resizeGraphics(qreal)), arenaItem, SLOT(updateGraphics(qreal)));
+            
             //TODO: use this function call
             //arenaItem->setElementId(m_game->getArena()->getCell(i,j).getElement()->getImageId());
             switch(m_game->getArena()->getCell(i,j).getType())
             {
                 case Cell::WALL:
-                    arenaItem->setElementId("arena_wall");
+                    arenaItem->setSpriteKey("arena_wall");
                     arenaItem->setZValue(-2);
                     break;
                 case Cell::HOLE:
@@ -239,33 +248,33 @@ void GameScene::init()
                     arenaItem = NULL;
                     break;
                 case Cell::ICE:
-                    arenaItem->setElementId("arena_ice");
+                    arenaItem->setSpriteKey("arena_ice");
                     arenaItem->setZValue(0);
                     break;
                 case Cell::BOMBMORTAR:
-                    arenaItem->setElementId("arena_bomb_mortar");
+                    arenaItem->setSpriteKey("arena_bomb_mortar");
                     arenaItem->setZValue(0);
                     break;
                 case Cell::ARROWUP:
-                    arenaItem->setElementId("arena_arrow_up");
+                    arenaItem->setSpriteKey("arena_arrow_up");
                     arenaItem->setZValue(0);
                     break;
                 case Cell::ARROWRIGHT:
-                    arenaItem->setElementId("arena_arrow_right");
+                    arenaItem->setSpriteKey("arena_arrow_right");
                     arenaItem->setZValue(0);
                     break;
                 case Cell::ARROWDOWN:
-                    arenaItem->setElementId("arena_arrow_down");
+                    arenaItem->setSpriteKey("arena_arrow_down");
                     arenaItem->setZValue(0);
                     break;
                 case Cell::ARROWLEFT:
-                    arenaItem->setElementId("arena_arrow_left");
+                    arenaItem->setSpriteKey("arena_arrow_left");
                     arenaItem->setZValue(0);
                     break;
                 case Cell::GROUND:
                 case Cell::BLOCK:
                 default:
-                    arenaItem->setElementId("arena_ground");
+                    arenaItem->setSpriteKey("arena_ground");
                     arenaItem->setZValue(-1);
             }
             m_arenaItem[i][j] = arenaItem;
@@ -285,66 +294,68 @@ void GameScene::init()
             {
                 // Create the element item and set the image
                 Block* block = dynamic_cast <Block*> (m_game->getArena()->getCell(i, j).getElement());
-                BlockItem* blockItem = new BlockItem(block);
-                blockItem->setSharedRenderer(m_rendererArenaItems);
-                blockItem->setElementId(block->getImageId());
+                BlockItem* blockItem = new BlockItem(block, m_rendererArenaItems);
+                connect(this, SIGNAL(resizeGraphics(qreal)), blockItem, SLOT(updateGraphics(qreal)));
+                blockItem->setSpriteKey(block->getImageId());
                 blockItem->update(block->getX(), block->getY());
                 blockItem->setZValue(200);
                 if(Settings::self()->showAllTiles() == 1)
                 {
                     blockItem->setZValue(99);
                 }
+                connect(this, SIGNAL(resizeGraphics(qreal)), blockItem, SLOT(updateGraphics(qreal)));
                 connect(blockItem, SIGNAL(blockItemDestroyed(BlockItem*)), this, SLOT(removeBlockItem(BlockItem*)));
                 m_blockItems[i][j] = blockItem;
                 // if the block contains a hidden bonus, create the bonus item 
                 Bonus* bonus = block->getBonus();
                 if(bonus)
                 {
-                    BonusItem* bonusItem = new BonusItem(bonus);
-                    bonusItem->setSharedRenderer(m_rendererBonusItems);
+                    BonusItem* bonusItem = new BonusItem(bonus, m_rendererBonusItems);
                     switch(bonus->getBonusType())
                     {
-                        case Bonus::SPEED:  bonusItem->setElementId("bonus_speed");
+                        case Bonus::SPEED:  bonusItem->setSpriteKey("bonus_speed");
                                             break;
-                        case Bonus::BOMB:   bonusItem->setElementId("bonus_bomb");
+                        case Bonus::BOMB:   bonusItem->setSpriteKey("bonus_bomb");
                                             break;
-                        case Bonus::POWER:  bonusItem->setElementId("bonus_power");
+                        case Bonus::POWER:  bonusItem->setSpriteKey("bonus_power");
                                             break;
-                        case Bonus::SHIELD: bonusItem->setElementId("bonus_shield");
+                        case Bonus::SHIELD: bonusItem->setSpriteKey("bonus_shield");
                                             break;
-                        case Bonus::THROW:  bonusItem->setElementId("bonus_throw");
+                        case Bonus::THROW:  bonusItem->setSpriteKey("bonus_throw");
                                             break;
-                        case Bonus::KICK:   bonusItem->setElementId("bonus_kick");
+                        case Bonus::KICK:   bonusItem->setSpriteKey("bonus_kick");
                                             break;
-                        case Bonus::HYPERACTIVE:   bonusItem->setElementId("bonus_bad_hyperactive");
+                        case Bonus::HYPERACTIVE:   bonusItem->setSpriteKey("bonus_bad_hyperactive");
                                             break;
-                        case Bonus::SLOW:   bonusItem->setElementId("bonus_bad_slow");
+                        case Bonus::SLOW:   bonusItem->setSpriteKey("bonus_bad_slow");
                                             break;
-                        case Bonus::MIRROR: bonusItem->setElementId("bonus_bad_mirror");
+                        case Bonus::MIRROR: bonusItem->setSpriteKey("bonus_bad_mirror");
                                             break;
-                        case Bonus::SCATTY: bonusItem->setElementId("bonus_bad_scatty");
+                        case Bonus::SCATTY: bonusItem->setSpriteKey("bonus_bad_scatty");
                                             break;
-                        case Bonus::RESTRAIN:   bonusItem->setElementId("bonus_bad_restrain");
+                        case Bonus::RESTRAIN:   bonusItem->setSpriteKey("bonus_bad_restrain");
                                             break;
-                        case Bonus::RESURRECT:   bonusItem->setElementId("bonus_neutral_resurrect");
+                        case Bonus::RESURRECT:   bonusItem->setSpriteKey("bonus_neutral_resurrect");
                                             break;
-                        default:            bonusItem->setElementId("bonus_neutral_pandora");
+                        default:            bonusItem->setSpriteKey("bonus_neutral_pandora");
                     }
                     
-                    if((qrand()/1.0)/RAND_MAX * 10 > 9 && bonusItem->elementId() != "bonus_neutral_resurrect")
+                    if((qrand()/1.0)/RAND_MAX * 10 > 9 && bonusItem->spriteKey() != "bonus_neutral_resurrect")
                     {
-                        bonusItem->setElementId("bonus_neutral_pandora");
+                        bonusItem->setSpriteKey("bonus_neutral_pandora");
                     }
                     
                     bonusItem->update(bonus->getX(), bonus->getY());
                     bonusItem->setZValue(100);
                     m_bonusItems[i][j] = bonusItem;
                     
+                    connect(this, SIGNAL(resizeGraphics(qreal)), bonusItem, SLOT(updateGraphics(qreal)));
                     connect(bonusItem, SIGNAL(bonusItemDestroyed(BonusItem*)), this, SLOT(removeBonusItem(BonusItem*)));
                     
-                    if(Settings::self()->showAllTiles() == 1)
+                    addItem(bonusItem);
+                    if(Settings::self()->showAllTiles() == 0)
                     {
-                        addItem(bonusItem);
+                        bonusItem->hide();
                     }
                 }
                 else
@@ -434,6 +445,12 @@ GameScene::~GameScene()
         delete m_playerItems[i];
     }
     
+    QMap <Player*, KGameRenderer*>::iterator iteratorRendererPlayer = m_mapRendererPlayerItems.begin();
+    while (iteratorRendererPlayer != m_mapRendererPlayerItems.end())
+    {
+        delete iteratorRendererPlayer.value();
+    }
+    
     removeItem(m_arenaBackground);
     delete m_arenaBackground;
     
@@ -442,7 +459,6 @@ GameScene::~GameScene()
     delete m_remainingTimeLabel;
     delete m_arenaNameLabel;
     
-    delete m_cache;
     delete m_rendererSelectedTheme;
     delete m_rendererDefaultTheme;
 }
@@ -530,6 +546,25 @@ void GameScene::cleanUp()
     }
 }
 
+KGameRenderer* GameScene::renderer(Element::Type type, Player* player)
+{
+    switch(type)
+    {
+        case Element::BLOCK:
+            return m_rendererArenaItems;
+        case Element::BONUS:
+            return m_rendererBonusItems;
+        case Element::BOMB:
+            return m_rendererBombItems;
+        case Element::PLAYER:
+            return m_mapRendererPlayerItems.value(player);
+        case Element::SCORE:
+            return m_rendererScoreItems;
+        default:
+            return NULL;
+    }
+}
+
 void GameScene::showScore()
 {
     m_infoOverlay->showScore();
@@ -543,126 +578,36 @@ void GameScene::resizeBackground()
         return;
     }
     
-    qreal x = views().at(0)->x();
-    qreal y = views().at(0)->y();
-    qreal width = views().at(0)->width();
-    qreal height = views().at(0)->height();
-    QPointF topLeftView = views().at(0)->mapToScene(0, 0);
-    QPointF bottomRightView = views().at(0)->mapToScene(width, height);
-    
-    x = topLeftView.x();
-    y = topLeftView.y();
-    width = bottomRightView.x() - x;
-    height = bottomRightView.y() - y;
-    
-    //calculate the scale factor between graphicsscene and graphicsview
-    //TODO: calcute with width and views().at(0)->width();
-    QPoint topLeft(0, 0);
-    QPoint bottomRight(100, 100);
-    topLeft = views().at(0)->mapFromScene(topLeft);
-    bottomRight = views().at(0)->mapFromScene(bottomRight);
-    m_SvgScaleFactor = 100.0 / (bottomRight.x() - topLeft.x());
-    
-    //get the graphicsview size
-    QSize svgSize = views().at(0)->size();
-    
-    //paint svg to pixmap
-    QPixmap pixmap;
-    pixmap = svgSize;
-    pixmap.fill(Qt::black);
-    QPainter painter(&pixmap);
-    m_rendererBackground->render(&painter, "background");
-    painter.end();
-    
-    //set pixmap
-    m_arenaBackground->setPixmap(pixmap);
-    m_arenaBackground->setPos(x, y);
-    m_arenaBackground->setScale(m_SvgScaleFactor);
-    m_arenaBackground->setShapeMode(QGraphicsPixmapItem::BoundingRectShape);
-    m_arenaBackground->setCacheMode(QGraphicsItem::DeviceCoordinateCache, svgSize);
+    //calculate the scaling factor for the SVGs
+    int horizontalPixelsPerCell = views().first()->size().width() / (m_minSize.width()/Cell::SIZE);
+    int verticalPixelsPerCell = views().first()->size().height() / (m_minSize.height()/Cell::SIZE);
+    if(horizontalPixelsPerCell < verticalPixelsPerCell)
+    {
+        m_SvgScaleFactor = Cell::SIZE / horizontalPixelsPerCell;
+    }
+    else
+    {
+        m_SvgScaleFactor = Cell::SIZE / verticalPixelsPerCell;
+    }
+    QTransform transform;
+    transform.scale(1/m_SvgScaleFactor, 1/m_SvgScaleFactor);
+    //transform.translate(-20,-10);
+    views().first()->setTransform(transform);
+    views().first()->centerOn(sceneRect().center());
+    views().first()->updateSceneRect(m_minSize);;
     
     //update pixmaps
-    updatePixmapGraphics();
+    emit resizeGraphics(m_SvgScaleFactor);
     
     //update overlay
-    m_infoOverlay->resizeDimmOverlay(x, y, width, height);
-}
-
-void GameScene::updatePixmapGraphics()
-{
-    if(views().isEmpty())
-    {
-        return;
-    }
+    QRect viewRect = views().first()->rect();
+    QRectF viewRectToScene = QRectF(views().first()->mapToScene(viewRect.topLeft()), views().first()->mapToScene(viewRect.bottomRight()));
+    m_infoOverlay->resizeDimmOverlay(viewRectToScene.x(), viewRectToScene.y(), viewRectToScene.width(), viewRectToScene.height());
     
-    qreal x = views().at(0)->x();
-    qreal y = views().at(0)->y();
-    qreal width = views().at(0)->width();
-    qreal height = views().at(0)->height();
-    QPointF topLeftView = views().at(0)->mapToScene(0, 0);
-    QPointF bottomRightView = views().at(0)->mapToScene(width, height);
-    QPixmap pixmap;
-    
-    x = topLeftView.x();
-    y = topLeftView.y();
-    width = bottomRightView.x() - x;
-    height = bottomRightView.y() - y;
-    
-    //calculate the scale factor between graphicsscene and graphicsview
-    //TODO: calcute with width and views().at(0)->width();
-    QPoint topLeft(0, 0);
-    QPoint bottomRight(100, 100);
-    topLeft = views().at(0)->mapFromScene(topLeft);
-    bottomRight = views().at(0)->mapFromScene(bottomRight);
-    m_SvgScaleFactor = 100.0 / (bottomRight.x() - topLeft.x());
-    
-    //the svg size
-    QSize svgSize;;
-    
-    //update the blast pixmaps
-    QString strElementID;
-    QString strDirection;
-    m_pixmapCache->clear();
-    for(int nDirection = BombExplosionItem::NORTH; nDirection < 4; nDirection++)
-    {
-        switch(nDirection)
-        {
-            case BombExplosionItem::NORTH:
-                strDirection = "north";
-                break;
-            case BombExplosionItem::EAST:
-                strDirection = "east";
-                break;
-            case BombExplosionItem::SOUTH:
-                strDirection = "south";
-                break;
-            case BombExplosionItem::WEST:
-                strDirection = "west";
-                break;
-        }
-        
-        for(int i = 0; i < 5; i++)
-        {
-            strElementID = QString("bomb_blast_%1_%2").arg(strDirection).arg(i);
-            svgSize = m_rendererBombItems->boundsOnElement(strElementID).size().toSize();
-            
-            QPoint topLeft(0, 0); 
-            topLeft = views().at(0)->mapFromScene(topLeft);
-            
-            QPoint bottomRight(svgSize.width(), svgSize.height()); 
-            bottomRight = views().at(0)->mapFromScene(bottomRight);
-            
-            svgSize.setHeight(bottomRight.y() - topLeft.y());
-            svgSize.setWidth(bottomRight.x() - topLeft.x());
-            
-            pixmap = svgSize;
-            pixmap.fill(Qt::transparent);
-            QPainter painter(&pixmap);
-            m_rendererBombItems->render(&painter, strElementID);
-            painter.end();
-            m_pixmapCache->insert(strElementID, pixmap);
-        }
-    }
+    //update background pixmap
+    m_arenaBackground->setRenderSize(viewRect.size());
+    m_arenaBackground->setPos(views().first()->mapToScene(viewRect.topLeft()));
+    m_arenaBackground->setScale(m_SvgScaleFactor);
 }
 
 Game* GameScene::getGame() const
@@ -672,16 +617,8 @@ Game* GameScene::getGame() const
 
 void GameScene::loadTheme()
 {
-    KGameTheme theme;
-    if (!theme.load(Settings::self()->theme()))
-    {
-        return;
-    }
-    if (!m_rendererSelectedTheme->load(theme.graphics()))
-    {
-        return;
-    }
-    m_cache->discard();
+    m_rendererSelectedTheme = new KGameRenderer(Settings::self()->theme());
+    
     update(0, 0, width(), height());
 
     // Update the theme config: if the default theme is selected, no theme entry is written -> the theme selector does not select the theme
@@ -800,17 +737,19 @@ void GameScene::updateInfo(const Game::InformationTypes p_info)
 void GameScene::createBombItem(Bomb* bomb)
 {
     // Create the Bombs
-    BombItem* bombItem = new BombItem(bomb);
-    bombItem->setSharedRenderer(m_rendererBombItems);
+    BombItem* bombItem = new BombItem(bomb, m_rendererBombItems);
     // Corrects the position of the BombItem
     bombItem->update(bomb->getX(), bomb->getY());
     addItem(bombItem);
     m_bombItems[bombItem].append(NULL);
     
+    bombItem->updateGraphics(m_SvgScaleFactor); //TODO: use a Renderer class and get the scale factor from a static function during initialization
+    
+    connect(this, SIGNAL(resizeGraphics(qreal)), bombItem, SLOT(updateGraphics(qreal)));
     connect(bomb, SIGNAL(mortar(int)), bombItem, SLOT(updateMortar(int)));
     connect(bomb, SIGNAL(bombDetonated(Bomb*)), this, SLOT(bombDetonated(Bomb*)));
     connect(bombItem, SIGNAL(bombItemFinished(BombItem*)), this, SLOT(removeBombItem(BombItem*)));
-    connect(bombItem, SIGNAL(animationFrameChanged(BombItem*, int)), this, SLOT(updateBombExplosionItemAnimation(BombItem*, int)));
+    connect(bombItem, SIGNAL(animationFrameChanged(BombItem*,int)), this, SLOT(updateBombExplosionItemAnimation(BombItem*,int)));
 }
 
 void GameScene::removeBombItem(BombItem* bombItem)
@@ -903,11 +842,7 @@ void GameScene::bombDetonated(Bomb* bomb)
                 if (m_bonusItems[nRow][nColumn] != NULL)
                 {
                     m_bonusItems[nRow][nColumn]->setUndestroyable(bomb->explosionID());
-                    
-                    if (!items().contains(m_bonusItems[nRow][nColumn]))
-                    {
-                        addItem(m_bonusItems[nRow][nColumn]);
-                    }
+                    m_bonusItems[nRow][nColumn]->show();
                 }
             }
         }
@@ -943,11 +878,7 @@ void GameScene::bombDetonated(Bomb* bomb)
                         if (m_bonusItems[nRow][nColumn] != NULL)
                         {
                             m_bonusItems[nRow][nColumn]->setUndestroyable(bomb->explosionID());
-                            
-                            if (!items().contains(m_bonusItems[nRow][nColumn]))
-                            {
-                                addItem(m_bonusItems[nRow][nColumn]);
-                            }
+                            m_bonusItems[nRow][nColumn]->show();
                         }
                     }
                 }
@@ -955,15 +886,10 @@ void GameScene::bombDetonated(Bomb* bomb)
                 {
                     m_bonusItems[nRow][nColumn]->initDestruction(bomb->explosionID());
                 }
-                bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::NORTH, nBombPower - i, m_pixmapCache, m_SvgScaleFactor);
-                if(bombExplosionItem->pixmapMissing())
-                {
-                    delete bombExplosionItem;
-                    updatePixmapGraphics();
-                    bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::NORTH, nBombPower - i, m_pixmapCache, m_SvgScaleFactor);
-                }
+                bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::NORTH, nBombPower - i, m_rendererBombItems, m_SvgScaleFactor);
                 bombExplosionItem->setPosition(bomb->getX(), bomb->getY() - (i+1)*Cell::SIZE);
                 bombExplosionItem->setZValue(300 + nBombPower+3 - i);
+                connect(this, SIGNAL(resizeGraphics(qreal)), bombExplosionItem, SLOT(updateGraphics(qreal)));
                 addItem(bombExplosionItem);
                 m_bombItems[bombItem].append(bombExplosionItem);
             }
@@ -1000,11 +926,7 @@ void GameScene::bombDetonated(Bomb* bomb)
                         if (m_bonusItems[nRow][nColumn] != NULL)
                         {
                             m_bonusItems[nRow][nColumn]->setUndestroyable(bomb->explosionID());
-                            
-                            if (!items().contains(m_bonusItems[nRow][nColumn]))
-                            {
-                                addItem(m_bonusItems[nRow][nColumn]);
-                            }
+                            m_bonusItems[nRow][nColumn]->show();
                         }
                     }
                 }
@@ -1012,15 +934,10 @@ void GameScene::bombDetonated(Bomb* bomb)
                 {
                     m_bonusItems[nRow][nColumn]->initDestruction(bomb->explosionID());
                 }
-                bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::EAST, nBombPower - i, m_pixmapCache, m_SvgScaleFactor);
-                if(bombExplosionItem->pixmapMissing())
-                {
-                    delete bombExplosionItem;
-                    updatePixmapGraphics();
-                    bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::EAST, nBombPower - i, m_pixmapCache, m_SvgScaleFactor);
-                }
+                bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::EAST, nBombPower - i, m_rendererBombItems, m_SvgScaleFactor);
                 bombExplosionItem->setPosition(bomb->getX() + (i+1)*Cell::SIZE, bomb->getY());
                 bombExplosionItem->setZValue(300 + nBombPower+3 - i);
+                connect(this, SIGNAL(resizeGraphics(qreal)), bombExplosionItem, SLOT(updateGraphics(qreal)));
                 addItem(bombExplosionItem);
                 m_bombItems[bombItem].append(bombExplosionItem);
             }
@@ -1057,11 +974,7 @@ void GameScene::bombDetonated(Bomb* bomb)
                         if (m_bonusItems[nRow][nColumn] != NULL)
                         {
                             m_bonusItems[nRow][nColumn]->setUndestroyable(bomb->explosionID());
-                            
-                            if (!items().contains(m_bonusItems[nRow][nColumn]))
-                            {
-                                addItem(m_bonusItems[nRow][nColumn]);
-                            }
+                            m_bonusItems[nRow][nColumn]->show();
                         }
                     }
                 }
@@ -1069,15 +982,10 @@ void GameScene::bombDetonated(Bomb* bomb)
                 {
                     m_bonusItems[nRow][nColumn]->initDestruction(bomb->explosionID());
                 }
-                bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::SOUTH, nBombPower - i, m_pixmapCache, m_SvgScaleFactor);
-                if(bombExplosionItem->pixmapMissing())
-                {
-                    delete bombExplosionItem;
-                    updatePixmapGraphics();
-                    bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::SOUTH, nBombPower - i, m_pixmapCache, m_SvgScaleFactor);
-                }
+                bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::SOUTH, nBombPower - i, m_rendererBombItems, m_SvgScaleFactor);
                 bombExplosionItem->setPosition(bomb->getX(), bomb->getY() + (i+1)*Cell::SIZE);
                 bombExplosionItem->setZValue(300 + nBombPower+3 - i);
+                connect(this, SIGNAL(resizeGraphics(qreal)), bombExplosionItem, SLOT(updateGraphics(qreal)));
                 addItem(bombExplosionItem);
                 m_bombItems[bombItem].append(bombExplosionItem);
             }
@@ -1114,11 +1022,7 @@ void GameScene::bombDetonated(Bomb* bomb)
                         if (m_bonusItems[nRow][nColumn] != NULL)
                         {
                             m_bonusItems[nRow][nColumn]->setUndestroyable(bomb->explosionID());
-                            
-                            if (!items().contains(m_bonusItems[nRow][nColumn]))
-                            {
-                                addItem(m_bonusItems[nRow][nColumn]);
-                            }
+                            m_bonusItems[nRow][nColumn]->show();
                         }
                     }
                 }
@@ -1126,15 +1030,10 @@ void GameScene::bombDetonated(Bomb* bomb)
                 {
                     m_bonusItems[nRow][nColumn]->initDestruction(bomb->explosionID());
                 }
-                bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::WEST, nBombPower - i, m_pixmapCache, m_SvgScaleFactor);
-                if(bombExplosionItem->pixmapMissing())
-                {
-                    delete bombExplosionItem;
-                    updatePixmapGraphics();
-                    bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::WEST, nBombPower - i, m_pixmapCache, m_SvgScaleFactor);
-                }
+                bombExplosionItem = new BombExplosionItem (bomb, BombExplosionItem::WEST, nBombPower - i, m_rendererBombItems, m_SvgScaleFactor);
                 bombExplosionItem->setPosition(bomb->getX() - (i+1)*Cell::SIZE, bomb->getY());
                 bombExplosionItem->setZValue(300 + nBombPower+3 - i);
+                connect(this, SIGNAL(resizeGraphics(qreal)), bombExplosionItem, SLOT(updateGraphics(qreal)));
                 addItem(bombExplosionItem);
                 m_bombItems[bombItem].append(bombExplosionItem);
             }
