@@ -27,14 +27,11 @@
 
 #include "commondefs.h"
 
-class KSvgRenderer;
-class KPixmapCache;
+class KGameRenderer;
 
 /**
  * This class is responsible for rendering all the game graphics.
  * Graphics is rendered from svg file specified by current theme.
- * QPixmaps which are returned are cached until setCellSize()
- * doesn't get called.
  * Only one instance of this class exists during a program run.
  * It can be accessed with static function KLinesRenderer::self().
  */
@@ -42,137 +39,147 @@ class KLinesRenderer
 {
 public:
     enum AnimationType { BornAnim, SelectedAnim, DieAnim, MoveAnim };
-    /**
-     * Returns one and the only instance of KLinesRenderer
-     */
-    static KLinesRenderer* self();
+
+    static void Init();
+    static void UnInit();
+
+    static inline KGameRenderer * renderer()
+    {
+        return m_renderer;
+    }
+    
     /**
      * Loads theme specified in preferences or a default one if none specified.
-     * Resets cache and puts new flashy rerendered pixmaps there
      */
-    bool loadTheme();
+    static bool loadTheme();
 
     /**
      * @return pixmap of the ball of color c in steady state
      */
-    QPixmap ballPixmap( BallColor c ) const;
+    static QString ballPixmapId(BallColor c);
+    static QPixmap ballPixmap(BallColor c);
     /**
      * @param type type of animation sequence
      * @param c color of the ball
      * @param frame frame number (must be between 0..numFrames(type)-1)
-     * @return pixmap containing animation frame
+     * @return string containing elementId
      */
-    QPixmap animationFrame( AnimationType type, BallColor c, int frame ) const;
+    static QString animationFrameId(AnimationType type, BallColor c, int frame);
     /**
      * @return pixmap for background painting.
      */
-    QPixmap backgroundPixmap(const QSize& size) const;
+    static QPixmap backgroundPixmap(const QSize& size);
     /**
      * @return pixmap for border surrounding the play field.
      * Will return an invalid QPixmap if no such element exists
      * in theme's svg file.
      * @see hasBorderElement
      */
-    QPixmap backgroundBorderPixmap( const QSize& size ) const;
+    static QPixmap backgroundBorderPixmap(const QSize& size);
     /**
      * @return pixmap of background tile (cell)
      */
-    QPixmap backgroundTilePixmap() const;
+    static QPixmap backgroundTilePixmap();
     /**
      * @return pixmap for PreviewItem
      */
-    QPixmap previewPixmap() const;
+    static QPixmap previewPixmap();
     /**
      * Sets render sizes for cells
      */
-    void setCellSize(int cellSize);
+    static void setCellSize(int cellSize);
     /**
      * @return current cell size
      */
-    int cellSize() const { return m_cellSize; }
+    static inline int cellSize()
+    {
+        return m_cellSize;
+    }
 
-    bool hasBorderElement() const;
+    static inline QSize cellExtent()
+    {
+        return QSize(m_cellSize, m_cellSize);
+    }
+
+    static bool hasBorderElement();
 
     /**
      * @return number of frames in animation sequence of type t
      */
-    inline int frameCount( AnimationType t ) const
+    static inline int frameCount(AnimationType t)
+    {
+        switch(t)
         {
-            switch(t)
-            {
-            case BornAnim:
-                return m_numBornFrames;
-            case SelectedAnim:
-                return m_numSelFrames;
-            case DieAnim:
-                return m_numDieFrames;
-            default: // e.g. Move - not handled here
-                return 0;
-            }
+        case BornAnim:
+            return m_numBornFrames;
+        case SelectedAnim:
+            return m_numSelFrames;
+        case DieAnim:
+            return m_numDieFrames;
+        default: // e.g. Move - not handled here
+            return 0;
         }
+    }
     /**
      * @return duration of animation sequence of type t
      */
-    inline int animDuration(AnimationType t) const
+    static inline int animDuration(AnimationType t)
+    {
+        switch(t)
         {
-            switch(t)
-            {
-            case BornAnim:
-                return m_bornDuration;
-            case SelectedAnim:
-                return m_selDuration;
-            case DieAnim:
-                return m_dieDuration;
-            case MoveAnim:
-                return m_moveDuration;
-            default:
-                return 0;
-            }
+        case BornAnim:
+            return m_bornDuration;
+        case SelectedAnim:
+            return m_selDuration;
+        case DieAnim:
+            return m_dieDuration;
+        case MoveAnim:
+            return m_moveDuration;
+        default:
+            return 0;
         }
+    }
 private:
     // disable copy - it's singleton
     KLinesRenderer();
-    KLinesRenderer( const KLinesRenderer& );
-    KLinesRenderer& operator=( const KLinesRenderer& );
+    KLinesRenderer(const KLinesRenderer&);
+    KLinesRenderer& operator=(const KLinesRenderer&);
     ~KLinesRenderer();
 
     /**
-     * Tries to find pixmap with cacheName in cache.
-     * If pixmap is not found in cache, this function will put it there
      * Pixmap is rendered according to current cellSize
      * If customSize is not passed, pixmap will be of (m_cellSize,m_cellSize) size
      *
      * @return rendered pixmap
      */
-    QPixmap pixmapFromCache(const QString& svgName, const QSize& customSize = QSize()) const;
+    static QPixmap getPixmap(const QString& svgName, const QSize& customSize = QSize());
 
     /**
      * Searches for "Default=true" keyword in all of the theme's desktop files in theme folder
      * and return this theme name in format like "themes/theme.desktop"
      */
-    QString findDefaultThemeName() const;
+    static QString findDefaultThemeName();
 
     /**
      *  This is the size of the scene's cell.
      *  All rendered pixmaps (except background) will have this size
      */
-    int m_cellSize;
+    static int m_cellSize;
     /**
      * Name of currently loaded theme
      */
-    QString m_currentTheme;
+    static QString m_currentTheme;
 
-    KSvgRenderer *m_renderer;
-    KPixmapCache *m_cache;
+    static KGameRenderer *m_renderer;
 
-    int m_numBornFrames;
-    int m_numSelFrames;
-    int m_numDieFrames;
+    static int m_numBornFrames;
+    static int m_numSelFrames;
+    static int m_numDieFrames;
 
-    int m_bornDuration;
-    int m_selDuration;
-    int m_dieDuration;
-    int m_moveDuration; // one cell
+    static int m_bornDuration;
+    static int m_selDuration;
+    static int m_dieDuration;
+    static int m_moveDuration; // one cell
 };
 
 #endif
