@@ -41,32 +41,32 @@
 
 class Fortyeight : public DealerScene
 {
-    friend class FortyeightSolver;
-
     Q_OBJECT
 
 public:
-    Fortyeight( );
-    virtual void restart();
-    virtual bool checkAdd( int checkIndex, const Pile *c1, const CardList& c2) const;
-    virtual QString getGameState();
-    virtual void setGameState( const QString & stream );
+    virtual void initialize();
 
-public slots:
-    virtual Card *newCards();
-    void deckClicked(Card *c);
+protected:
+    virtual void setGameState( const QString & state );
+    virtual QString getGameState() const;
+    virtual bool checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const;
+    virtual bool checkRemove(const PatPile* pile, const QList<KCard*> & cards) const;
+    virtual void cardsDroppedOnPile( const QList<KCard*> & cards, KCardPile * pile );
+    virtual void restart( const QList<KCard*> & cards );
+
+protected slots:
+    virtual bool newCards();
 
 private:
-    void deal();
+    bool canPutStore( const KCardPile * pile, const QList<KCard*> &cards ) const;
 
-    Pile *talon;
-    Pile *stack[8];
-    Pile *target[8];
-    Pile *pile;
+    PatPile *talon;
+    PatPile *stack[8];
+    PatPile *target[8];
+    PatPile *pile;
     bool lastdeal;
+
+    friend class FortyeightSolver;
 };
 
 #endif
-
-
-//-------------------------------------------------------------------------//
