@@ -41,7 +41,7 @@
 #include "patsolve/patsolve.h"
 
 #include "KCardTheme"
-#include "KStandardCardDeck"
+#include "KCardDeck"
 
 #include <KAboutData>
 #include <KApplication>
@@ -59,26 +59,25 @@
 #include <QtXml/QDomDocument>
 
 #include <climits>
-
+#include <time.h>
 
 static DealerScene *getDealer( int wanted_game )
 {
     foreach ( DealerInfo * di, DealerInfoList::self()->games() )
     {
-        if ( di->ids().contains( wanted_game ) )
+        if ( di->providesId( wanted_game ) )
         {
             DealerScene * d = di->createGame();
             Q_ASSERT( d );
-            d->setDeck( new KStandardCardDeck( KCardTheme(), d ) );
+            d->setDeck( new KCardDeck( KCardTheme(), d ) );
             d->initialize();
 
             if ( !d->solver() )
             {
-                kError() << "There is no solver for" << di->name();
+                kError() << "There is no solver for" << di->nameForId( wanted_game );;
                 return 0;
             }
 
-            fprintf( stdout, "Testing %s\n", di->name() );
             return d;
         }
     }
@@ -99,7 +98,6 @@ QString lowerAlphaNum( const QString & string )
     return result;
 }
 
-
 int main( int argc, char **argv )
 {
     KAboutData aboutData( "kpat",
@@ -165,12 +163,14 @@ int main( int argc, char **argv )
     QStringList gameList;
     foreach ( const DealerInfo *di, DealerInfoList::self()->games() )
     {
-        const QString translatedKey = lowerAlphaNum( ki18n( di->name() ).toString(tmpLocale) );
+        KLocalizedString localizedKey = ki18n( di->untranslatedBaseName().constData() );
+        const QString translatedKey = lowerAlphaNum( localizedKey.toString( tmpLocale ) );
         gameList << translatedKey;
-        indexMap.insert( translatedKey, di->ids().first() );
-        indexMap.insert( lowerAlphaNum( QString( di->name() ) ), di->ids().first() );
+        indexMap.insert( translatedKey, di->baseId() );
+        indexMap.insert( lowerAlphaNum( QString::fromUtf8( di->untranslatedBaseName() ) ), di->baseId() );
     }
     gameList.sort();
+    const QString listSeparator = ki18nc( "List separator", ", " ).toString( tmpLocale );
     delete tmpLocale;
 
     KCmdLineArgs::init( argc, argv, &aboutData );
@@ -180,13 +180,15 @@ int main( int argc, char **argv )
     options.add("solve <num>", ki18n("Dealer to solve (debug)" ));
     options.add("start <num>", ki18n("Game range start (default 0:INT_MAX)" ));
     options.add("end <num>", ki18n("Game range end (default start:start if start given)" ));
-    options.add("gametype <game>", ki18n("Skip the selection screen and load a particular game type. Valid values are: %1").subs(gameList.join(i18nc("List separator", ", "))));
+    options.add("gametype <game>", ki18n("Skip the selection screen and load a particular game type. Valid values are: %1").subs(gameList.join(listSeparator)));
+    options.add("testdir <directory>", ki18n( "Directory with test cases" ) );
+    options.add("generate", ki18n( "Generate random test cases" ) );
     options.add("+file", ki18n("File to load"));
     KCmdLineArgs::addCmdLineOptions (options);
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
 
     KApplication application;
-    KGlobal::locale()->insertCatalog("libkdegames");
+    KGlobal::locale()->insertCatalog( QLatin1String( "libkdegames" ));
 
     QString savegame = args->getOption( "solvegame" );
     if ( !savegame.isEmpty() )
@@ -198,7 +200,7 @@ int main( int argc, char **argv )
 
         DealerScene *f = getDealer( doc.documentElement().attribute("id").toInt() );
 
-        f->openGame( doc );
+        f->openGame( &of );
         f->solver()->translate_layout();
         int ret = f->solver()->patsolve();
         if ( ret == Solver::SolutionExists )
@@ -211,6 +213,44 @@ int main( int argc, char **argv )
         return 0;
     }
 
+    QString testdir = args->getOption("testdir");
+    if ( !testdir.isEmpty() ) {
+       qsrand(time(0));
+       if ( args->isSet("generate") ) {
+          for (int dealer = 0; dealer < 20; dealer++) {
+              DealerScene *f = getDealer( dealer );
+              if (!f) continue;
+              int count = 100;
+              QTime mytime;
+              while (count) {
+                if (f->deck()) f->deck()->stopAnimations();
+                int i = qrand() % INT_MAX;
+                f->startNew( i );
+                mytime.start();
+                f->solver()->translate_layout();
+                int ret = f->solver()->patsolve();
+                if ( ret == Solver::SolutionExists ) {
+                   fprintf( stdout, "%d: %d won (%d ms)\n", dealer, i, mytime.elapsed() );
+                   count--;
+                   QFile file(QString("%1/%2-%3-1").arg(testdir).arg(dealer).arg(i));
+                   file.open( QFile::WriteOnly );
+                   f->saveGame( &file );
+                }
+                else if ( ret == Solver::NoSolutionExists ) {
+                   fprintf( stdout, "%d: %d lost (%d ms)\n", dealer, i, mytime.elapsed()  );
+                   count--;
+                   QFile file(QString("%1/%2-%3-0").arg(testdir).arg(dealer).arg(i));
+                   file.open( QFile::WriteOnly );
+                   f->saveGame( &file );
+                } else {
+                   fprintf( stdout, "%d: %d unknown (%d ms)\n", dealer, i, mytime.elapsed() );
+                }
+             }
+          }
+       } 
+       return 0;
+    }
+
     bool ok = false;
     int wanted_game = -1;
     if ( args->isSet( "solve" ) )
@@ -242,6 +282,7 @@ int main( int argc, char **argv )
         for ( int i = start_index; i <= end_index; i++ )
         {
             mytime.start();
+            f->deck()->stopAnimations();
             f->startNew( i );
             f->solver()->translate_layout();
             int ret = f->solver()->patsolve();
@@ -262,7 +303,7 @@ int main( int argc, char **argv )
     MainWindow *w = new MainWindow;
     if (args->count())
     {
-        if (!w->openGame(args->url(0)))
+        if ( !w->loadGame( args->url( 0 ), true ) )
             w->slotShowGameSelectionScreen();
     }
     else if (indexMap.contains(gametype))
@@ -271,9 +312,8 @@ int main( int argc, char **argv )
     }
     else if (savedState.exists())
     {
-        if (!w->openGame(savedState.fileName(), false))
+        if ( !w->loadGame( savedState.fileName(), false ) )
             w->slotShowGameSelectionScreen();
-        savedState.remove();
     }
     else
     {
