@@ -297,7 +297,12 @@ void KSquaresWindow::gameOver(const QVector<KSquaresPlayer> &_playerList)
 void KSquaresWindow::playerTakeTurn(KSquaresPlayer* currentPlayer)
 {
 	//kDebug() << "void KSquares::playerTakeTurn(KSquaresPlayer* currentPlayer)";
-	statusBar()->changeItem(currentPlayer->name(), statusplayer); //TODO Add player's colour
+	statusBar()->changeItem(
+		QString::fromLatin1("<font color=\"%1\">%2</font>")
+			.arg(currentPlayer->colour().name())
+			.arg(currentPlayer->name()),
+		statusplayer
+	);
 	if(currentPlayer->isHuman())
 	{
 		//Let the human player interact with the board through the GameBoardView
@@ -330,11 +335,11 @@ void KSquaresWindow::setupActions()
 
 	KAction *a_rankings = new KAction(this);
 	a_rankings->setText(i18n("Online rankings"));
-	actionCollection()->addAction("rankings", a_rankings);
+	actionCollection()->addAction( QLatin1String( "rankings" ), a_rankings);
 
 	KAction *a_seats = new KAction(this);
 	a_seats->setText(i18n("List of seats"));
-	actionCollection()->addAction("seats", a_seats);
+	actionCollection()->addAction( QLatin1String( "seats" ), a_seats);
 
 	// Game
 	if(!KGGZMod::Module::instance())
@@ -374,7 +379,7 @@ void KSquaresWindow::optionsPreferences()
 	ui_prefs_ai.setupUi(aiSettingsDialog);
 	dialog->addPage(aiSettingsDialog, i18n("Computer Player"), "games-difficult");
 
-	connect(dialog, SIGNAL(settingsChanged(const QString &)), m_view, SLOT(setBoardSize()));
+	connect(dialog, SIGNAL(settingsChanged(QString)), m_view, SLOT(setBoardSize()));
 	dialog->show();
 }
 
@@ -385,8 +390,8 @@ void KSquaresWindow::slotNetworkData(int fd)
 		m_proto = new dots();
 		m_proto->ggzcomm_set_fd(fd);
 		connect(m_proto,
-			SIGNAL(signalNotification(dotsOpcodes::Opcode, const msg&)),
-			SLOT(slotNetworkPacket(dotsOpcodes::Opcode, const msg&)));
+			SIGNAL(signalNotification(dotsOpcodes::Opcode,msg)),
+			SLOT(slotNetworkPacket(dotsOpcodes::Opcode,msg)));
 		connect(m_proto, SIGNAL(signalError()), SLOT(slotNetworkError()));
 	}
 
