@@ -18,9 +18,9 @@
 
 
 static const KLocalizedString description = ki18n("Potato game for kids");
-static const KLocalizedString text = ki18n("A program original by <email address='%1'>Éric Bischoff</email>\nand John Calhoun.\n\nThis program is dedicated to my daughter Sunniva.").subs("ebischoff@nerim.net");
+static const KLocalizedString text = ki18n("A program original by <email address='%1'>Éric Bischoff</email>\nand John Calhoun.\n\nThis program is dedicated to my daughter Sunniva.").subs(QLatin1String("ebischoff@nerim.net"));
 
-static const char version[] = "0.6.0";
+static const char version[] = "0.8.0";
 
 // Main function
 int main(int argc, char *argv[])
@@ -43,7 +43,7 @@ int main(int argc, char *argv[])
   KCmdLineArgs::addCmdLineOptions(options);
 
   KApplication app;
-  KGlobal::locale()->insertCatalog("libkdegames");
+  KGlobal::locale()->insertCatalog( QLatin1String( "libkdegames" ));
 
   TopLevel *toplevel=0;
 
